from .pip_command import *
from .pip_install import *

__author__ = "pavelgs"
__version__ = "0.0.1"
__email__ = "p6282813@yandex.ru"
